@@ -1,12 +1,10 @@
+import logging
 import tempfile
 from functools import wraps
 from pathlib import Path
 from time import time
-from urllib import request
 
-import click
-import rasterio as rio
-from rasterio.plot import show
+log = logging.getLogger(__name__)
 
 
 def timing(f):
@@ -14,24 +12,18 @@ def timing(f):
     def wrap(*args, **kw):
         ts = time()
         # start_msg = f"{f.__name__} ..."
-        # click.echo(f"{start_msg:<40s}", nl=False)
+        # log.debug(f"{start_msg:<40s}")
         result = f(*args, **kw)
         te = time()
         end_msg = f"✅ ({round(te - ts, 1)}s)"
-        click.echo(f"{end_msg:<20s}")
+        log.debug(end_msg)
         return result
 
     return wrap
 
 
-@timing
-def download_file(url: str, local_file: Path) -> Path:
-    request.urlretrieve(url, local_file)
-    return local_file
-
-
 def TMPDIR() -> Path:
-    tmpdir = Path(tempfile.gettempdir()) / "map2stl"
+    tmpdir = Path(tempfile.gettempdir()) / "mapa"
     if not tmpdir.is_dir():
         tmpdir.mkdir()
     return tmpdir
@@ -43,8 +35,3 @@ def _path_to_merged_tiff(bbox_hash: str) -> Path:
 
 def _path_to_clipped_tiff(bbox_hash: str) -> Path:
     return TMPDIR() / f"clipped_{bbox_hash}.tiff"
-
-
-def show_tiff(path: Path) -> None:
-    tiff = rio.open(path)
-    show((tiff, 1), cmap="terrain")
